<?php
namespace Teknisa\PLA\Modules\Cardapio\Controllers;

use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use \Zeedhi\Framework\DTO\Response\Error;
use \Zeedhi\Framework\DTO\Request\DataSet;
use Zeedhi\Framework\DataSource;

class Pla00106AnaliseCustoPlanejadoController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName = "analisecustoplanejado";
    protected $parameterBagColumns = array(
        "NRORG",
        "CDFILCUSPLA", 
        "CDSERVCUSPLA",
        "NRCONSPLAN",
        "IDTIPOCUSTOPLA"
    );

	protected $entityManager;
    protected $newCode;
    protected $connection;
    protected $environment;

    public function __construct($crudService, $parameterBag, $entityManager, $newCode, $connection, $environment) {
        $this->crudService   = $crudService;
        $this->parameterBag  = $parameterBag;
        $this->entityManager = $entityManager;
        $this->newCode       = $newCode;
        $this->connection    = $connection;
        $this->environment   = $environment;
    }
    
    public function deleteconsplan(\Zeedhi\Framework\DTO\Request $request, \Zeedhi\Framework\DTO\Response $response){
        $rowt = $request->getRow();
        
        $params = array(
            "P_NRCONSPLAN" => $rowt['NRCONSPLAN'],
            "P_CDFILICPLA" => $rowt['CDFILICPLA'],
            "P_NRORG" => $rowt['NRORG']
        );
        $sql = "DELETE FROM CONSPLAN WHERE NRCONSPLAN = :P_NRCONSPLAN AND CDFILICPLA = :P_CDFILICPLA AND NRORG = :P_NRORG";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }

    public function calculoCusto(\Zeedhi\Framework\DTO\Request $request, \Zeedhi\Framework\DTO\Response $response) {
        try {
            $rows = $request->getRow();

            $nrorg           = $this->environment->getNrOrg();
            $cdoperador      = $this->environment->getCdOperador();
            $cdfilial        = $rows['cdfilial'];
            $cdservfili      = $rows['cdservfili'];
            $nrtipocustopla  = $rows['nrtipocustopla'];
            $nrtipocustoreal = $rows['nrtipocustoreal'];
            $dtinicial       = $rows['dtinicial'];
            $dtfinal         = $rows['dtfinal'];
            $dtrefecusto     = $rows['dtrefecusto'];
            $idarquivo       = $rows['idarquivo'];
            $idprodutos      = $rows['idprodutos'];
            $idsepprato      = $rows['idsepprato'];
            $peacrescimo     = $rows['peacrescimo'];
            $idarredond      = $rows['idarredond'];
            $cdprodutoini    = $rows['cdprodutoini'];
            $cdprodutofin    = $rows['cdprodutofin'];
            $cdfilicalccusto = $rows['cdfilicalccusto'];
            $contador        = 'CONSPLAN' . $cdfilial;

            $nrconsplan = $this->newCode->getCodeByTableName($contador, $nrorg);
 
            $connection = $this->entityManager->getConnection();
            $procedure = new StoredProcedure($connection, 'PLA_ANALISE_CUSTO_CARDAPIO');
            $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $cdfilial, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDSERVFILI', Param::PARAM_INPUT, $cdservfili, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $dtinicial, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $dtfinal, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDARQUIVO', Param::PARAM_INPUT, $idarquivo, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDPRODUTOS', Param::PARAM_INPUT, $idprodutos, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDSEPPRATO', Param::PARAM_INPUT, $idsepprato, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_PEACRESCIMO', Param::PARAM_INPUT, $peacrescimo, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDARREDOND', Param::PARAM_INPUT, $idarredond, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRCONSPLAN', Param::PARAM_INPUT, $nrconsplan, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDPRODUTOINI', Param::PARAM_INPUT, $cdprodutoini, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDPRODUTOFIN', Param::PARAM_INPUT, $cdprodutofin, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $cdoperador, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILICALCCUSTO', Param::PARAM_INPUT, $cdfilicalccusto, Param::PARAM_TYPE_STR, 0));
            $procedure->addParam(new Param('P_NRTIPOCUSTOPLA', Param::PARAM_INPUT, $nrtipocustopla, Param::PARAM_TYPE_STR, 0));
            $procedure->addParam(new Param('P_NRTIPOCUSTOREAL', Param::PARAM_INPUT, $nrtipocustoreal, Param::PARAM_TYPE_STR, 0));
            $procedure->addParam(new Param('P_DTREFECUSTO', Param::PARAM_INPUT, $dtrefecusto, Param::PARAM_TYPE_STR, 0));
            $procedure->addParam(new Param('P_NRORG', Param::PARAM_INPUT, $nrorg, Param::PARAM_TYPE_STR, 0));
            $procedure->addParam(new Param('P_IDEXCLUI_CONSPLAN', Param::PARAM_INPUT, 'N', Param::PARAM_TYPE_STR));
            $procedure->execute();

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet ('nrconsplan', array($nrconsplan)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
}